Crate idax_sys

Crate idax_sys 

Raw FFI bindings to the idax C++ IDA SDK wrapper library.

This crate provides unsafe extern "C" function declarations generated by bindgen from the idax C shim layer. Use the idax crate for safe, idiomatic Rust bindings.

Structs

IdaxAddressRange
IdaxBackendInfo
IdaxBasicBlock
IdaxChunk
Chunk descriptor.
IdaxDataTypedValue
IdaxDatabaseCompilerInfo
IdaxDatabaseImportModule
IdaxDatabaseImportSymbol
IdaxDatabaseSnapshot
IdaxDebuggerAppcallOptions
IdaxDebuggerAppcallRequest
IdaxDebuggerAppcallResult
IdaxDebuggerAppcallValue
IdaxDebuggerExceptionInfo
IdaxDebuggerModuleInfo
IdaxDebuggerRegisterInfo
IdaxDecompilerCursorPositionEvent
IdaxDecompilerExpressionInfo
IdaxDecompilerHintRequestEvent
IdaxDecompilerItemAtPosition
IdaxDecompilerMaturityEvent
IdaxDecompilerPseudocodeEvent
IdaxDecompilerStatementInfo
IdaxEntryPoint
IdaxEvent
Flat C transfer model for ida::event::Event.
IdaxFixup
IdaxFixupCustomHandler
IdaxFrameVariable
Stack frame variable.
IdaxFunction
Flat C representation of a function snapshot.
IdaxGraphCallbacks
IdaxGraphEdge
IdaxGraphEdgeInfo
IdaxGraphNodeInfo
IdaxInstruction
Flat C representation of a decoded instruction.
IdaxLineRenderEntry
IdaxLoaderLoadFlags
IdaxLocalVariable
IdaxLuminaBatchResult
IdaxNameEntry
IdaxOperand
Flat C representation of an instruction operand.
IdaxPerformanceCounters
IdaxPluginActionContext
IdaxPopupEvent
IdaxRegisterVariable
IdaxRenderingEvent
IdaxSegment
Flat C representation of a segment snapshot.
IdaxShowWidgetOptions
IdaxStackFrame
IdaxThreadInfo
IdaxTypeEnumMember
IdaxTypeEnumMemberInput
IdaxTypeMember
IdaxUIEvent
IdaxXref
Flat C representation of a cross-reference.

Constants

IDAX_ERROR_CONFLICT
IDAX_ERROR_INTERNAL
IDAX_ERROR_NONE
IDAX_ERROR_NOT_FOUND
IDAX_ERROR_SDK_FAILURE
IDAX_ERROR_UNSUPPORTED
IDAX_ERROR_VALIDATION
IdaxDataTypedValueKind_IDAX_DATA_TYPED_ARRAY
IdaxDataTypedValueKind_IDAX_DATA_TYPED_BYTES
IdaxDataTypedValueKind_IDAX_DATA_TYPED_FLOATING_POINT
IdaxDataTypedValueKind_IDAX_DATA_TYPED_POINTER
IdaxDataTypedValueKind_IDAX_DATA_TYPED_SIGNED_INTEGER
IdaxDataTypedValueKind_IDAX_DATA_TYPED_STRING
IdaxDataTypedValueKind_IDAX_DATA_TYPED_UNSIGNED_INTEGER
IdaxDebuggerAppcallValueKind_IDAX_DEBUGGER_APPCALL_ADDRESS
IdaxDebuggerAppcallValueKind_IDAX_DEBUGGER_APPCALL_BOOLEAN
IdaxDebuggerAppcallValueKind_IDAX_DEBUGGER_APPCALL_FLOATING_POINT
IdaxDebuggerAppcallValueKind_IDAX_DEBUGGER_APPCALL_SIGNED_INTEGER
IdaxDebuggerAppcallValueKind_IDAX_DEBUGGER_APPCALL_STRING
IdaxDebuggerAppcallValueKind_IDAX_DEBUGGER_APPCALL_UNSIGNED_INTEGER
IdaxDebuggerBreakpointChange_IDAX_DEBUGGER_BREAKPOINT_ADDED
IdaxDebuggerBreakpointChange_IDAX_DEBUGGER_BREAKPOINT_CHANGED
IdaxDebuggerBreakpointChange_IDAX_DEBUGGER_BREAKPOINT_REMOVED

Functions

idax_address_find_first
idax_address_find_next
idax_address_is_code
idax_address_is_data
idax_address_is_head
idax_address_is_loaded
idax_address_is_mapped
idax_address_is_tail
idax_address_is_unknown
idax_address_item_end
idax_address_item_size
idax_address_item_start
idax_address_next_head
idax_address_next_mapped
idax_address_next_not_tail
idax_address_prev_head
idax_address_prev_mapped
idax_address_prev_not_tail
idax_analysis_cancel
idax_analysis_is_enabled
idax_analysis_is_idle
idax_analysis_revert_decisions
idax_analysis_schedule
idax_analysis_schedule_code
idax_analysis_schedule_function
idax_analysis_schedule_range
idax_analysis_schedule_reanalysis
idax_analysis_schedule_reanalysis_range
idax_analysis_set_enabled
idax_analysis_wait
idax_analysis_wait_range
idax_backend_info_free
idax_basic_block_free
idax_comment_add_anterior
idax_comment_add_posterior
idax_comment_anterior_lines
idax_comment_append
idax_comment_clear_anterior
idax_comment_clear_posterior
idax_comment_get
idax_comment_get_anterior
idax_comment_get_posterior
idax_comment_lines_free
idax_comment_posterior_lines
idax_comment_remove
idax_comment_remove_anterior_line
idax_comment_remove_posterior_line
idax_comment_render
idax_comment_set
idax_comment_set_anterior
idax_comment_set_anterior_lines
idax_comment_set_posterior
idax_comment_set_posterior_lines
idax_data_define_byte
idax_data_define_double
idax_data_define_dword
idax_data_define_float
idax_data_define_oword
idax_data_define_qword
idax_data_define_string
idax_data_define_struct
idax_data_define_tbyte
idax_data_define_word
idax_data_find_binary_pattern
idax_data_original_byte
idax_data_original_dword
idax_data_original_qword
idax_data_original_word
idax_data_patch_byte
idax_data_patch_bytes
idax_data_patch_dword
idax_data_patch_qword
idax_data_patch_word
idax_data_read_byte
idax_data_read_bytes
idax_data_read_dword
idax_data_read_qword
idax_data_read_string
idax_data_read_typed
idax_data_read_word
idax_data_revert_patch
idax_data_revert_patches
idax_data_typed_value_free
idax_data_undefine
idax_data_write_byte
idax_data_write_bytes
idax_data_write_dword
idax_data_write_qword
idax_data_write_typed
idax_data_write_word
idax_database_abi_name
idax_database_address_bitness
idax_database_address_span
idax_database_close
idax_database_compiler_info
idax_database_compiler_info_free
idax_database_file_to_database
idax_database_file_type_name
idax_database_image_base
idax_database_import_modules
idax_database_import_modules_free
idax_database_init
idax_database_input_file_path
idax_database_input_md5
idax_database_is_big_endian
idax_database_is_snapshot_database
idax_database_loader_format_name
idax_database_max_address
idax_database_memory_to_database
idax_database_min_address
idax_database_open
idax_database_open_binary
idax_database_open_non_binary
idax_database_processor_id
idax_database_processor_name
idax_database_save
idax_database_set_snapshot_description
idax_database_snapshots
idax_database_snapshots_free
idax_debugger_add_breakpoint
idax_debugger_appcall
idax_debugger_appcall_result_free
idax_debugger_appcall_value_free
idax_debugger_appcall_with_executor
idax_debugger_attach
idax_debugger_available_backends
idax_debugger_cleanup_appcall
idax_debugger_current_backend
idax_debugger_current_thread_id
idax_debugger_detach
idax_debugger_has_breakpoint
idax_debugger_instruction_pointer
idax_debugger_is_custom_register
idax_debugger_is_floating_register
idax_debugger_is_integer_register
idax_debugger_is_request_running
idax_debugger_load_backend
idax_debugger_on_breakpoint_changed
idax_debugger_on_breakpoint_hit
idax_debugger_on_exception
idax_debugger_on_library_loaded
idax_debugger_on_library_unloaded
idax_debugger_on_process_exited
idax_debugger_on_process_started
idax_debugger_on_process_suspended
idax_debugger_on_thread_exited
idax_debugger_on_thread_started
idax_debugger_on_trace
idax_debugger_read_memory
idax_debugger_register_executor
idax_debugger_register_info
idax_debugger_register_info_free
idax_debugger_register_value
idax_debugger_remove_breakpoint
idax_debugger_request_attach
idax_debugger_request_resume
idax_debugger_request_resume_thread
idax_debugger_request_run_to
idax_debugger_request_select_thread
idax_debugger_request_start
idax_debugger_request_step_into
idax_debugger_request_step_out
idax_debugger_request_step_over
idax_debugger_request_suspend
idax_debugger_request_suspend_thread
idax_debugger_resume
idax_debugger_resume_thread
idax_debugger_run_requests
idax_debugger_run_to
idax_debugger_select_thread
idax_debugger_set_register
idax_debugger_stack_pointer
idax_debugger_start
idax_debugger_state
idax_debugger_step_into
idax_debugger_step_out
idax_debugger_step_over
idax_debugger_suspend
idax_debugger_suspend_thread
idax_debugger_terminate
idax_debugger_thread_count
idax_debugger_thread_id_at
idax_debugger_thread_name_at
idax_debugger_threads
idax_debugger_unregister_executor
idax_debugger_unsubscribe
idax_debugger_write_memory
idax_decompiled_declaration
idax_decompiled_entry_address
idax_decompiled_free
idax_decompiled_get_comment
idax_decompiled_header_line_count
idax_decompiled_line_to_address
idax_decompiled_lines
idax_decompiled_lines_free
idax_decompiled_microcode
idax_decompiled_pseudocode
idax_decompiled_raw_lines
idax_decompiled_rename_variable
idax_decompiled_save_comments
idax_decompiled_set_comment
idax_decompiled_set_raw_line
idax_decompiled_variable_count
idax_decompiled_variables
idax_decompiled_variables_free
idax_decompiler_available
idax_decompiler_current_view
idax_decompiler_decompile
idax_decompiler_for_each_expression
idax_decompiler_for_each_item
idax_decompiler_item_at_position
idax_decompiler_item_type_name
idax_decompiler_mark_dirty
idax_decompiler_mark_dirty_with_callers
idax_decompiler_on_create_hint
idax_decompiler_on_curpos_changed
idax_decompiler_on_func_printed
idax_decompiler_on_maturity_changed
idax_decompiler_on_refresh_pseudocode
idax_decompiler_pseudocode_header_line_count
idax_decompiler_pseudocode_lines_free
idax_decompiler_raw_pseudocode_lines
idax_decompiler_register_microcode_filter
idax_decompiler_set_pseudocode_line
idax_decompiler_unregister_microcode_filter
idax_decompiler_unsubscribe
idax_decompiler_view_for_function
idax_decompiler_view_from_host
idax_diagnostics_log
idax_diagnostics_log_level
idax_diagnostics_performance_counters
idax_diagnostics_reset_performance_counters
idax_diagnostics_set_log_level
idax_entry_add
idax_entry_by_index
idax_entry_by_ordinal
idax_entry_clear_forwarder
idax_entry_count
idax_entry_forwarder
idax_entry_free
idax_entry_rename
idax_entry_set_forwarder
idax_event_on_byte_patched
idax_event_on_comment_changed
idax_event_on_event
idax_event_on_event_filtered
idax_event_on_function_added
idax_event_on_function_deleted
idax_event_on_renamed
idax_event_on_segment_added
idax_event_on_segment_deleted
idax_event_subscribe
idax_event_unsubscribe
idax_fixup_at
idax_fixup_contains
idax_fixup_exists
idax_fixup_find_custom
idax_fixup_first
idax_fixup_in_range
idax_fixup_next
idax_fixup_prev
idax_fixup_register_custom
idax_fixup_remove
idax_fixup_set
idax_fixup_unregister_custom
idax_frame_variable_free
idax_free_addresses
Free a malloc’d uint64 array returned by an idax function.
idax_free_bytes
Free a malloc’d byte array returned by an idax function.
idax_free_string
Free a malloc’d string returned by an idax function.
idax_function_add_register_variable
idax_function_add_tail
idax_function_at
idax_function_by_index
idax_function_callees
idax_function_callers
idax_function_chunk_count
idax_function_chunks
idax_function_code_addresses
idax_function_comment
idax_function_count
idax_function_create
idax_function_define_stack_variable
idax_function_find_register_variable
idax_function_frame
idax_function_frame_variable_by_name
idax_function_frame_variable_by_offset
idax_function_free
Free strings inside an IdaxFunction.
idax_function_has_register_variables
idax_function_is_outlined
idax_function_item_addresses
idax_function_name_at
idax_function_reanalyze
idax_function_register_variables
idax_function_remove
idax_function_remove_register_variable
idax_function_remove_tail
idax_function_rename_register_variable
idax_function_set_comment
idax_function_set_end
idax_function_set_outlined
idax_function_set_start
idax_function_sp_delta_at
idax_function_update
idax_graph_activate_graph_viewer
idax_graph_add_edge
idax_graph_add_edge_with_info
idax_graph_add_node
idax_graph_clear
idax_graph_close_graph_viewer
idax_graph_create
idax_graph_create_group
idax_graph_current_layout
idax_graph_delete_group
idax_graph_edges
idax_graph_flowchart
idax_graph_flowchart_for_ranges
idax_graph_flowchart_free
idax_graph_free
idax_graph_free_edges
idax_graph_free_node_ids
idax_graph_group_members
idax_graph_has_graph_viewer
idax_graph_is_collapsed
idax_graph_is_graph_viewer_visible
idax_graph_is_group
idax_graph_node_exists
idax_graph_path_exists
idax_graph_predecessors
idax_graph_redo_layout
idax_graph_refresh_graph
idax_graph_remove_edge
idax_graph_remove_node
idax_graph_replace_edge
idax_graph_set_group_expanded
idax_graph_set_layout
idax_graph_show_graph
idax_graph_successors
idax_graph_total_node_count
idax_graph_visible_node_count
idax_graph_visible_nodes
idax_instruction_call_targets
idax_instruction_clear_operand_representation
idax_instruction_code_refs_from
idax_instruction_create
idax_instruction_data_refs_from
idax_instruction_decode
idax_instruction_free
Free all malloc’d fields inside an IdaxInstruction.
idax_instruction_get_forced_operand
idax_instruction_has_fall_through
idax_instruction_is_call
idax_instruction_is_conditional_jump
idax_instruction_is_jump
idax_instruction_is_return
idax_instruction_jump_targets
idax_instruction_next
idax_instruction_operand_byte_width
idax_instruction_operand_register_class
idax_instruction_operand_register_name
idax_instruction_operand_struct_offset_path
idax_instruction_operand_struct_offset_path_names
idax_instruction_operand_text
idax_instruction_prev
idax_instruction_set_forced_operand
idax_instruction_set_operand_based_struct_offset
idax_instruction_set_operand_binary
idax_instruction_set_operand_character
idax_instruction_set_operand_decimal
idax_instruction_set_operand_float
idax_instruction_set_operand_format
idax_instruction_set_operand_hex
idax_instruction_set_operand_octal
idax_instruction_set_operand_offset
idax_instruction_set_operand_stack_variable
idax_instruction_set_operand_struct_offset_by_id
idax_instruction_set_operand_struct_offset_by_name
idax_instruction_string_array_free
idax_instruction_text
idax_instruction_toggle_operand_negate
idax_instruction_toggle_operand_sign
idax_last_error_category
Get the error category from the last failed call (thread-local).
idax_last_error_code
Get the error code from the last failed call (thread-local).
idax_last_error_message
Get the error message from the last failed call (thread-local). Returns a pointer to a thread-local buffer. Do NOT free.
idax_lines_colstr
idax_lines_decode_addr_tag
idax_lines_make_addr_tag
idax_lines_tag_advance
idax_lines_tag_remove
idax_lines_tag_strlen
idax_loader_abort_load
idax_loader_create_filename_comment
idax_loader_decode_load_flags
idax_loader_encode_load_flags
idax_loader_file_to_database
idax_loader_input_filename
idax_loader_input_read_bytes
idax_loader_input_read_bytes_at
idax_loader_input_read_string
idax_loader_input_seek
idax_loader_input_size
idax_loader_input_tell
idax_loader_memory_to_database
idax_loader_set_processor
idax_local_variable_free
idax_lumina_close_all_connections
idax_lumina_close_connection
idax_lumina_has_connection
idax_lumina_pull
idax_lumina_push
idax_name_all_user_defined
idax_name_demangled
idax_name_entries_free
idax_name_force_set
idax_name_get
idax_name_is_auto_generated
idax_name_is_public
idax_name_is_user_defined
idax_name_is_valid_identifier
idax_name_is_weak
idax_name_remove
idax_name_resolve
idax_name_sanitize_identifier
idax_name_set
idax_name_set_public
idax_name_set_weak
idax_plugin_action_context_decompiler_view_host
idax_plugin_action_context_widget_host
idax_plugin_action_context_with_decompiler_view_host
idax_plugin_action_context_with_widget_host
idax_plugin_attach_to_menu
idax_plugin_attach_to_popup
idax_plugin_attach_to_toolbar
idax_plugin_detach_from_menu
idax_plugin_detach_from_popup
idax_plugin_detach_from_toolbar
idax_plugin_register_action
idax_plugin_register_action_ex
idax_plugin_unregister_action
idax_register_variable_free
idax_register_variables_free
idax_search_binary_pattern
idax_search_immediate
idax_search_next_code
idax_search_next_data
idax_search_next_defined
idax_search_next_error
idax_search_next_unknown
idax_search_text
idax_segment_at
idax_segment_by_index
idax_segment_by_name
idax_segment_comment
idax_segment_count
idax_segment_create
idax_segment_free
Free strings inside an IdaxSegment (does NOT free the struct itself).
idax_segment_move
idax_segment_next
idax_segment_prev
idax_segment_remove
idax_segment_resize
idax_segment_set_bitness
idax_segment_set_class
idax_segment_set_comment
idax_segment_set_default_segment_register
idax_segment_set_default_segment_register_for_all
idax_segment_set_name
idax_segment_set_permissions
idax_segment_set_type
idax_stack_frame_free
idax_storage_node_alt_get
idax_storage_node_alt_remove
idax_storage_node_alt_set
idax_storage_node_blob_get
idax_storage_node_blob_remove
idax_storage_node_blob_set
idax_storage_node_blob_size
idax_storage_node_blob_string
idax_storage_node_free
idax_storage_node_hash_get
idax_storage_node_hash_set
idax_storage_node_id
idax_storage_node_name
idax_storage_node_open
idax_storage_node_open_by_id
idax_storage_node_sup_get
idax_storage_node_sup_set
idax_thread_info_free
idax_type_add_member
idax_type_apply
idax_type_apply_named
idax_type_array_element_type
idax_type_array_length
idax_type_array_of
idax_type_by_name
idax_type_calling_convention
idax_type_clone
idax_type_create_struct
idax_type_create_union
idax_type_enum_members
idax_type_enum_members_free
idax_type_enum_type
idax_type_float32
idax_type_float64
idax_type_free
idax_type_from_declaration
idax_type_function_argument_types
idax_type_function_return_type
idax_type_function_type
idax_type_handle_array_free
idax_type_import
idax_type_int8
idax_type_int16
idax_type_int32
idax_type_int64
idax_type_is_array
idax_type_is_enum
idax_type_is_floating_point
idax_type_is_function
idax_type_is_integer
idax_type_is_pointer
idax_type_is_struct
idax_type_is_typedef
idax_type_is_union
idax_type_is_variadic_function
idax_type_is_void
idax_type_load_library
idax_type_local_type_count
idax_type_local_type_name
idax_type_member_by_name
idax_type_member_by_offset
idax_type_member_count
idax_type_member_free
idax_type_members
idax_type_members_free
idax_type_pointee_type
idax_type_pointer_to
idax_type_remove
idax_type_resolve_typedef
idax_type_retrieve
idax_type_retrieve_operand
idax_type_save_as
idax_type_size
idax_type_to_string
idax_type_uint8
idax_type_uint16
idax_type_uint32
idax_type_uint64
idax_type_unload_library
idax_type_void
idax_ui_activate_widget
idax_ui_ask_address
idax_ui_ask_file
idax_ui_ask_form
idax_ui_ask_long
idax_ui_ask_string
idax_ui_ask_yn
idax_ui_attach_dynamic_action
idax_ui_close_custom_viewer
idax_ui_close_widget
idax_ui_create_custom_viewer
idax_ui_create_widget
idax_ui_custom_viewer_current_line
idax_ui_custom_viewer_jump_to_line
idax_ui_custom_viewer_line_count
idax_ui_find_widget
idax_ui_info
idax_ui_is_widget_visible
idax_ui_jump_to
idax_ui_message
idax_ui_on_current_widget_changed
idax_ui_on_cursor_changed
idax_ui_on_database_closed
idax_ui_on_database_inited
idax_ui_on_event
idax_ui_on_event_filtered
idax_ui_on_popup_ready
idax_ui_on_ready_to_run
idax_ui_on_rendering_info
idax_ui_on_screen_ea_changed
idax_ui_on_view_activated
idax_ui_on_view_closed
idax_ui_on_view_created
idax_ui_on_view_deactivated
idax_ui_on_widget_closing
idax_ui_on_widget_closing_for_widget
idax_ui_on_widget_invisible
idax_ui_on_widget_invisible_for_widget
idax_ui_on_widget_visible
idax_ui_on_widget_visible_for_widget
idax_ui_refresh_all_views
idax_ui_refresh_custom_viewer
idax_ui_register_timer
idax_ui_register_timer_with_callback
idax_ui_rendering_event_add_entry
idax_ui_screen_address
idax_ui_selection
idax_ui_set_custom_viewer_lines
idax_ui_show_widget
idax_ui_show_widget_ex
idax_ui_subscribe
idax_ui_unregister_timer
idax_ui_unsubscribe
idax_ui_user_directory
idax_ui_warning
idax_ui_widget_host
idax_ui_widget_id
idax_ui_widget_title
idax_ui_widget_type
idax_ui_with_widget_host
idax_xref_add_code
idax_xref_add_data
idax_xref_code_refs_from
idax_xref_code_refs_from_range
idax_xref_code_refs_to
idax_xref_code_refs_to_range
idax_xref_data_refs_from
idax_xref_data_refs_from_range
idax_xref_data_refs_to
idax_xref_data_refs_to_range
idax_xref_refs_from
idax_xref_refs_from_range
idax_xref_refs_to
idax_xref_refs_to_range
idax_xref_remove_code
idax_xref_remove_data

Type Aliases

IdaxActionEnabledCheck
IdaxActionEnabledCheckEx
IdaxActionHandler
IdaxActionHandlerEx
IdaxDataTypedValueKind
IdaxDebuggerAppcallExecutorCallback
IdaxDebuggerAppcallExecutorCleanupCallback
IdaxDebuggerAppcallValueKind
IdaxDebuggerBreakpointChange
IdaxDebuggerBreakpointChangedCallback
IdaxDebuggerBreakpointHitCallback
IdaxDebuggerExceptionCallback
IdaxDebuggerLibraryLoadedCallback
IdaxDebuggerLibraryUnloadedCallback
IdaxDebuggerProcessExitedCallback
IdaxDebuggerProcessStartedCallback
IdaxDebuggerProcessSuspendedCallback
IdaxDebuggerThreadExitedCallback
IdaxDebuggerThreadStartedCallback
IdaxDebuggerTraceCallback
IdaxDecompiledHandle
Opaque handle to a decompiled function. Must be freed with idax_decompiled_free().
IdaxDecompilerCreateHintCallback
IdaxDecompilerCursorPositionCallback
IdaxDecompilerExpressionVisitor
IdaxDecompilerMaturityChangedCallback
IdaxDecompilerPseudocodeCallback
IdaxDecompilerStatementVisitor
IdaxDecompilerToken
IdaxEventBytePatchedCallback
IdaxEventCallback
Legacy generic event callback. Kept for backwards compatibility.
IdaxEventCommentChangedCallback
IdaxEventExCallback
IdaxEventFilterCallback
IdaxEventFunctionAddedCallback
IdaxEventFunctionDeletedCallback
IdaxEventRenamedCallback
IdaxEventSegmentAddedCallback
IdaxEventSegmentDeletedCallback
IdaxGraphHandle
Opaque handle to a graph. Must be freed with idax_graph_free().
IdaxGraphOnClicked
IdaxGraphOnCreatingGroup
IdaxGraphOnDestroyed
IdaxGraphOnDoubleClicked
IdaxGraphOnHint
IdaxGraphOnNodeColor
IdaxGraphOnNodeText
IdaxGraphOnRefresh
IdaxMicrocodeApplyCallback
IdaxMicrocodeMatchCallback
IdaxNodeHandle
Opaque handle to a storage node. Must be freed with idax_storage_node_free().
IdaxPluginHostCallback
IdaxTypeHandle
Opaque type handle. Must be freed with idax_type_free().
IdaxUIActionCallback
IdaxUIEventCallback
IdaxUIEventExCallback
IdaxUIEventFilterCallback
IdaxUIPopupCallback
IdaxUIRenderingCallback
IdaxUITimerCallback
IdaxWidgetHandle
Opaque widget handle.
IdaxWidgetHostCallback